/* sde.c - solve the SDE using stochastic Euler method
 *
 * Copyright (C) 2010  Jochen Voss
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA.
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <time.h>

#include "strange.h"
#include "random4.h"

int
main()
{
  struct jvrand *rng;
  const double q = SDE_SIGMA*sqrt(DU);
  double  x1, x2;
  int  i;

  rng = new_jvrand(time(NULL));

  x1 = 1;
  x2 = 0;
  printf("0.0 %f %f\n", x1, x2);
  for (i=1; i<=NU; ++i) {
    double  s2 = sin(x2);
    double  c1 = cos(x1);

    x1 += -2*s2*DU + q*jvrand_standard_normal(rng);
    x2 +=  2*c1*DU + q*jvrand_standard_normal(rng);
    printf("%f %f %f\n", i*DU, x1, x2);
  }

  delete_jvrand(rng);
  return 0;
}
