/* strange.h - shared header file for the strange SPDE
 *
 * Copyright (C) 2009, 2010  Jochen Voss
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

#ifndef FILE_STRANGE_H_SEEN
#define FILE_STRANGE_H_SEEN

#include <stdlib.h>		/* for malloc etc */
#include <math.h>		/* for M_PI */


#define SEED 316759616


/* model parameters */

#define SDE_SIGMA 0.5
#define PARAM_nu (1.0/(SDE_SIGMA*SDE_SIGMA))
#define PARAM_sigma M_SQRT2

#define UMAX (2*M_PI)
#define TMAX 1.0

/* discretisation parameters */

#define NU 10000
#define DU (UMAX/NU)

#define DT 1e-6
#define THETA 0.5


/* memory allocation helpers */

#define xnew(T,N) ((T *)malloc((N)*sizeof(T)))
#define xfree(P) free(P)

/* from "direct.c" */
extern void xmul(int n, double Al, double Am, double Ar,
		 const double *restrict in, double *restrict out);
extern void solve(int n, double Al, double Am, double Ar,
		  const double *restrict rhs, double *restrict x);

#endif /* FILE_STRANGE_H_SEEN */
