/* burgers.h - shared header file for the Burgers' SPDE code
 *
 * Copyright (C) 2009, 2010  Jochen Voss
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

#ifndef FILE_BURGERS_H_SEEN
#define FILE_BURGERS_H_SEEN

#include <stdlib.h>		/* for malloc etc */
#include <math.h>		/* for M_PI */


#define SEED 1829308863


/* model parameters */

#define PARAM_nu 1.0

#define UMAX (2*M_PI)
#define TMAX 0.1

/* discretisation parameters */

#define NU 20000
#define COARSEN 4	   /* the coarse grid has NU/COARSEN points */

#define DT .5e-4
#define THETA 0.5

#define DEGREE 6


/* memory allocation helpers */

#define xnew(T,N) ((T *)malloc((N)*sizeof(T)))
#define xfree(P) free(P)

/* from "direct.c" */
extern void xmul(int n, double Al, double Am, double Ar,
		 const double *restrict in, double *restrict out);
extern void solve(int n, double Al, double Am, double Ar,
		  const double *restrict rhs, double *restrict x);

/* from "wrong_fe.c" */
extern void wrong_fe(int n, double *x, int l);

/* from "good_fe.c" */
extern void good_fe(int n, double *x, int corr_deg, const double *corr_coeff);

/* from "pool.c" */
struct factory;

extern  struct factory *new_factory(int n_workers);
extern  void  delete_factory(struct factory *f);
extern  void  factory_job_start(struct factory *f,
				void (*fn)(void *), void *data);
extern  int  factory_job_finish(struct factory *f, void *data);

/* from "simplex.c" */
extern double simplex(int n, double *x, const double *eps, double size_limit,
		      double (*fn)(const double *x, void *data), void *data);

#endif /* FILE_BURGERS_H_SEEN */
