/* burgers.h - shared header file for the Burgers' SPDE code
 *
 * Copyright (C) 2009, 2010  Jochen Voss
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

#ifndef FILE_BURGERS_H_SEEN
#define FILE_BURGERS_H_SEEN

#include <stdlib.h>		/* for malloc etc */
#include <math.h>		/* for M_PI */


#define SEED 84494648


/* model parameters */

#define UMAX (2*M_PI)
#define TMAX 2.0

/* discretisation parameters */

#define DT (1e-5)
#define THETA 0.5


/* memory allocation helpers */

#define xnew(T,N) ((T *)malloc((N)*sizeof(T)))
#define xfree(P) free(P)

/* from "direct.c" */
extern void xmul(int n, double Al, double Am, double Ar,
		 const double *restrict in, double *restrict out);
extern void solve(int n, double Al, double Am, double Ar,
		  const double *restrict rhs, double *restrict x);

/* from "pool.c" */
struct factory;

extern  struct factory *new_factory(int n_workers);
extern  void  delete_factory(struct factory *f);
extern  void  factory_job_start(struct factory *f,
				void (*fn)(void *), void *data);
extern  int  factory_job_finish(struct factory *f, void *data);

#endif /* FILE_BURGERS_H_SEEN */
