#! /usr/bin/env python

from __future__ import division

from math import sqrt, log10

adjust = {
    ("-2.5", None): "above left",
    ("-2.5", "-1"): "below left,xshift=2pt",
    ("-2.5", "-3"): "above left,xshift=10pt",
    ("-2.5", "-4"): "above left,xshift=10pt",
    ("-2.5", "-5"): "left,yshift=3pt,xshift=4pt",
    ("-4.0", None): "above right,xshift=-8pt,yshift=2pt",
    ("-4.0", "-4"): "below=-2pt,xshift=2pt",
    ("-4.0", "-5"): "right,xshift=-8pt,yshift=-2pt",
}

f = open("../fig7.tikz", "w")
f.write(r"""\begin{tikzpicture}[scale=5]
\fill (0,0) circle (.3pt) node[below] {$c=1$};
\fill (-1,0) circle (.3pt) node[below] {$c=0$};
\draw[thin] (-1.5,0) -- (0.5,0);
""")

for k, delta in enumerate(["-4.0", "-3.5", "-3.0", "-2.5"]):
    res = []
    for l in file("res%s.dat"%delta):
        eps, a, b = map(float, l.split())
        x = (a**2 - b**2 - 1)/2
        y = sqrt(a**2 - (1+x)**2)
        res.append((eps, x, y))

    for i in range(1, len(res)-1, 4):
        eps, x, y = res[i]
        dx = res[i+1][1] - res[i-1][1]
        dy = res[i+1][2] - res[i-1][2]
        l = sqrt(dx*dx + dy*dy)
        dx, dy = dx/l, dy/l
        tag = "%g"%log10(eps)
        label = r"$\scriptstyle\varepsilon=10^{%s}$"%tag
        if k == 0:
            pos = adjust.get((delta,tag), "right")
            args = (x+.01*dy, y-.01*dx, x-.01*dy, y+.01*dx, pos, label)
            s = r"\draw (%f,%f) -- (%f,%f) node[%s] {%s}"%args
        elif k == 3:
            pos = adjust.get((delta,tag), "left")
            args = (x-.01*dy, y+.01*dx, x+.01*dy, y-.01*dx, pos, label)
            s = r"\draw (%f,%f) -- (%f,%f) node[%s] {%s}"%args
        else:
            args = (x+.01*dy, y-.01*dx, x-.01*dy, y+.01*dx)
            s = r"\draw (%f,%f) -- (%f,%f)"%args
        f.write(s+";\n")
    label = r"$\delta=10^{%s}$"%delta
    pos = adjust.get((delta,None), "above")
    f.write(r"\draw "+" -- ".join("(%f,%f)"%(x,y) for eps, x, y in reversed(res))+" node[%s]{%s};\n"%(pos,label))

f.write(r"""\end{tikzpicture}
""")
f.close()
